var group__annotation__utils =
[
    [ "vrna_annotate_covar_db", "group__annotation__utils.html#ga01fad860df6c799264d1186c343b1d29", null ],
    [ "vrna_annotate_covar_pairs", "group__annotation__utils.html#gadb9ba32197f05d5876d389b2ba92edac", null ]
];